@@ -1,6 +1,6 @@
 /*
 
- $Id: arch.cpp,v 1.40.2.2 2002/04/30 11:15:34 helio Exp $
+ $Id: arch.cpp,v 1.40.2.4 2002/06/15 00:07:13 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -320,7 +320,7 @@ void Arch::slotReceivedTOC(KProcess*, char* _data, int _length)
 	m_buffer = "";
   }
   if(!m_finished)
-	m_buffer = (_data + startChar);	// Copy what's left of the buffer
+	m_buffer.append(_data + startChar);	// Append what's left of the buffer
 
   _data[_length] = c;
 }
