@@ -1,6 +1,6 @@
 /*
 
-  $Id: compressedfile.cpp,v 1.2 2002/01/21 06:31:41 waba Exp $
+  $Id: compressedfile.cpp,v 1.2.2.1 2002/06/13 00:29:01 helio Exp $
 
     ark: A program for modifying archives via a GUI.
 
@@ -306,7 +306,10 @@ void CompressedFile::unarchFile(QStringList *, const QString & _destDir,
     {
       QString dest;
       if (_destDir.isEmpty() || _destDir.isNull())
-	dest = m_settings->getExtractDir();
+	{
+	  kdError(1601) << "There was no extract directory given." << endl;
+	  return;
+	}
       else
 	dest=_destDir;
       QString command;
