@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: dirDlg.h,v 1.7 2000/06/22 20:19:23 ezust Exp $
+ $Id: dirDlg.h,v 1.8.4.1 2002/06/13 00:29:01 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -10,6 +10,7 @@
  1997-1999: Rob Palmbos palm9744@kettering.edu
  1999: Francois-Xavier Duranceau duranceau@kde.org
  2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
+ 2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -30,53 +31,69 @@
 #ifndef DIRDLG_H
 #define DIRDLG_H
 
-// Qt includes
-#include <qdialog.h>
-
-// ark includes
-#include "arksettings.h"
-
-class QListBoxItem;
-class QLabel;
-class QLineEdit;
+class QString;
+class QWidget;
+class QListBox;
 class QRadioButton;
-class QButtonGroup;
+class QWidgetStack;
 
-enum { NUM_RADIOS = 3, NUM_DIR_TYPES = 4 };
+class KURLRequester;
 
-class WidgetHolder
-{
-public:
-  void hide();
-  void show();
-  friend class DirDlg;
-private:
-  QLabel *lDirType, *lHorizLine;
-  QLineEdit *fixedLE;
-  QButtonGroup *buttonGroup;
-  QRadioButton *radios[NUM_RADIOS];
-};
+class ArkSettings;
 
-class DirDlg : public QDialog 
+enum DirType { StartupDir, OpenDir, ExtractDir, AddDir };
+
+class DirWidget : public QWidget
 {
   Q_OBJECT
+
 public:
-  DirDlg(  ArkSettings *d, QWidget *parent=0, const char *name=0 );
+
+  DirWidget( DirType type, QWidget *parent=0, const char *name=0 );
+
+signals:
+
+  void favDirChanged( const QString & );
+
+protected slots:
+
+  void slotFavDirChanged( const QString & );
+
+public:
+
+  KURLRequester *dirFav, *dirFixed;
+  QButtonGroup *btnGroup;
+  QRadioButton *rbFav, *rbFixed, *rbLast;
+};
+
+class DirDlg : public QWidget
+{
+  Q_OBJECT
+
+public:
+
+  DirDlg(ArkSettings *d, QWidget *parent=0, const char *name=0);
   ~DirDlg();
-  static QString getDirType(int item);
+
 public slots:
-  void getFavDir();	
-  void getFixedDir();
+
   void saveConfig();
   void dirTypeChanged(int _dirType);
+
+signals:
+
+  void favDirChanged( const QString & );
+
 private: // methods  
+
   void initConfig();
-  void createRepeatingWidgets();
+  QWidgetStack* createWidgetStack();
   void hideWidgets();
+
 private: // data
+
+  QWidgetStack *stack;
   ArkSettings *data;
-  WidgetHolder *widgets[NUM_DIR_TYPES]; // pointers to the widgets
-  QLineEdit *favLE;  // the favorite directory
   QListBox *pListBox;
 };
 
