@@ -1,6 +1,6 @@
 /*
 
- $Id: lha.cpp,v 1.1 2001/10/25 16:26:05 maragato Exp $
+ $Id: lha.cpp,v 1.1.2.1 2002/06/13 00:29:01 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -271,13 +271,16 @@ void LhaArch::unarchFile(QStringList *_fileList, const QString & _destDir,
 			 bool viewFriendly)
 {
   // if _fileList is empty, we extract all.
-  // if _destDir is empty, look at settings for extract directory
+  // if _destDir is empty, abort with error.
 
   kdDebug(1601) << "+LhaArch::unarchFile" << endl;
   QString dest;
 
   if (_destDir.isEmpty() || _destDir.isNull())
-    dest = m_settings->getExtractDir();
+    {
+      kdError(1601) << "There was no extract directory given." << endl;
+      return;
+    }
   else dest = _destDir;
 
   QString tmp;
