@@ -1,6 +1,6 @@
 /*
 
- $Id: rar.cpp,v 1.1 2001/10/25 16:26:05 maragato Exp $
+ $Id: rar.cpp,v 1.1.2.1 2002/06/13 00:29:01 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -84,7 +84,7 @@ bool RarArch::processLine(const QCString &line)
   char columns[11][80];
   char filename[4096];
   sscanf(QFile::encodeName(m_line1), " %[^\n]", filename);
-  sscanf((const char *)m_line2.ascii(), " %[0-9] %[0-9] %[0-9%] %2[0-9]-%2[0-9]-%2[0-9] %5[0-9:] %[drwxlst-] %[A-F0-9] %[A-Za-z0-9] %[0-9.]",
+  sscanf((const char *)m_line2.ascii(), " %[0-9] %[0-9] %[0-9%<>-] %2[0-9]-%2[0-9]-%2[0-9] %5[0-9:] %[drwxlst-] %[A-F0-9] %[A-Za-z0-9] %[0-9.]",
 	 columns[0], columns[1], columns[2], columns[3],
 	 columns[8], columns[9], columns[10],
 	 columns[4], columns[5], columns[6],
@@ -259,13 +259,16 @@ void RarArch::unarchFile(QStringList *_fileList, const QString & _destDir,
 			 bool viewFriendly)
 {
   // if _fileList is empty, we extract all.
-  // if _destDir is empty, look at settings for extract directory
+  // if _destDir is empty, abort with error.
 
   kdDebug(1601) << "+RarArch::unarchFile" << endl;
 
   QString dest;
   if (_destDir.isEmpty() || _destDir.isNull())
-    dest = m_settings->getExtractDir();
+    {
+      kdError(1601) << "There was no extract directory given." << endl;
+      return;
+    }
   else dest = _destDir;
 
   KProcess *kp = new KProcess;
