@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.h,v 1.4 2000/03/09 19:38:14 ezust Exp $
+ $Id: shellOutputDlg.h,v 1.6 2001/09/01 13:45:04 mueller Exp $
 
  ark -- archiver for the KDE project
 
@@ -28,18 +28,19 @@
 #ifndef SHELL_OUTPUT_DLG_H
 #define SHELL_OUTPUT_DLG_H
 
-// Qt includes
-#include <qdialog.h>
 #include <qmultilineedit.h>
+#include <qdialog.h>
 
-// ark includes
-#include "arksettings.h"
+class QWidget;
 
+class ArkSettings;
 
 class ShellOutputWidget : public QMultiLineEdit {
 public:
   ShellOutputWidget( QDialog* _d ) : QMultiLineEdit( _d ) 
-    { setNumCols(80); };
+    { setWordWrap(FixedColumnWidth);
+      setWrapColumnOrWidth(80);
+     };
 };
 
 
