@@ -1,6 +1,6 @@
 /*
 
- $Id: tar.cpp,v 1.4.2.1 2002/04/30 11:15:34 helio Exp $
+ $Id: tar.cpp,v 1.4.2.2 2002/06/13 00:29:01 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -689,7 +689,10 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
   QString dest;
 
   if (_destDir.isEmpty() || _destDir.isNull())
-    dest = m_settings->getExtractDir();
+    {
+      kdError(1601) << "There was no extract directory given." << endl;
+      return;
+    }
   else dest = _destDir;
 
   QString tmp;
