@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc_core.cpp,v 1.46.2.2 2002/04/18 22:31:35 neundorf Exp $
+    $Id: kcalc_core.cpp,v 1.46.2.3 2002/08/05 15:53:22 mlaurent Exp $
 
     kCalculator, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -405,7 +405,7 @@ void QtCalculator::EnterDigit(int data)
 void QtCalculator::SubtractDigit()
 {
 	// This function could be better, possibly, but am I glad to see it!
-	if (DISPLAY_AMOUNT != 0)
+	if (DISPLAY_AMOUNT != 0 || decimal_point!=0)
 	{
                 if (current_base == NB_DECIMAL && (DISPLAY_AMOUNT != floor(DISPLAY_AMOUNT)))
                 {
