@@ -1,5 +1,5 @@
 /*
- * $Id: kdf.cpp,v 1.19 2001/01/10 09:04:36 mlaurent Exp $
+ * $Id: kdf.cpp,v 1.24 2002/01/09 11:28:02 winkvist Exp $
  *
  * kdf.cpp - KDiskFree
  *
@@ -21,33 +21,32 @@
  *
  */
 
-#include <kapp.h>
-#include <kconfig.h>
-#include <klocale.h>
+#include <kapplication.h>
 #include <kstdaccel.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
 #include "kdf.h"
+#include <kpopupmenu.h>
 
 static const char *description =
 	I18N_NOOP("KDE free disk space utility");
 
-static const char *version = "v0.0.1";
+static const char *version = "v0.5";
 
 
 /***************************************************************/
 KDFTopLevel::KDFTopLevel(QWidget *, const char *name)
   : KMainWindow(0, name)
 {
-  kdf = new KDFWidget(this,"kdf",FALSE); CHECK_PTR(kdf);
+  kdf = new KDFWidget(this,"kdf",FALSE); Q_CHECK_PTR(kdf);
 
-  QPopupMenu *file = new QPopupMenu; CHECK_PTR(file);
+  QPopupMenu *file = new QPopupMenu; Q_CHECK_PTR(file);
   file->insertItem( i18n( "&Update" ), kdf, SLOT(updateDF()) );
   file->insertSeparator();
-  file->insertItem( i18n( "&Quit" ), this, SLOT(close()), KStdAccel::key(KStdAccel::Quit) );
+  file->insertItem( i18n( "&Quit" ), this, SLOT(close()), KStdAccel::shortcut(KStdAccel::Quit) );
 
-  QPopupMenu *option = new QPopupMenu; CHECK_PTR(option);
+  QPopupMenu *option = new QPopupMenu; Q_CHECK_PTR(option);
   option->insertItem( i18n("&Configure %1...").arg(kapp->caption()),
 		      kdf, SLOT(settingsBtnClicked()) );
 
@@ -89,7 +88,7 @@ int main(int argc, char **argv)
     for( int n=1; KDFTopLevel::canBeRestored(n); n++ )
     {
       KDFTopLevel *ktl = new KDFTopLevel();
-      CHECK_PTR(ktl);
+      Q_CHECK_PTR(ktl);
       app.setMainWidget(ktl);
       ktl->restore(n);
     }
@@ -97,7 +96,7 @@ int main(int argc, char **argv)
   else
   {
     KDFTopLevel *ktl = new KDFTopLevel();
-    CHECK_PTR(ktl);
+    Q_CHECK_PTR(ktl);
     ktl->show();
   }
 
