@@ -232,7 +232,7 @@ class CHexEditorWidget : public QWidget
     QString  mWorkDir; // Remembers last directroy used by file dialogs 
  
     uint mUntitledCount;
-    QList<CHexBuffer> mDocumentList;
+    QPtrList<CHexBuffer> mDocumentList;
     SDisplayState mDisplayState;
 
     CProgress     mProgressData;
