@@ -19,31 +19,27 @@
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qpopupmenu.h>
-#include <qkeycode.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qdir.h>
-#include <qlineedit.h>
 #include <qobjectlist.h>
-#include <qtooltip.h>
-#include <qscrollbar.h>
-#include <qcollection.h>
 #include <qclipboard.h>
+#include <qtimer.h>
+#include <qcursor.h>
 
 #include <kaccel.h>
 #include <kaction.h>
+#include <kstdaccel.h>
 #include <kstdaction.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include <kdebug.h>
-
-#include <kiconloader.h>
+#include <kpopupmenu.h>
 #include <kkeydialog.h>
+#include <klocale.h>
 #include <kmenubar.h>
 #include <kmessagebox.h>
-#include <kstddirs.h>
-#include <ktoolbar.h>
+#include <kopenwith.h>
+#include <krun.h>
+#include <kstandarddirs.h>
+#include <kurl.h>
 
 extern "C" {
 #include <unistd.h>
@@ -55,19 +51,15 @@ extern "C" {
 // #include "ReadListConf.h"
 #include "cpopmenu.h"
 #include "optiondialog.h"
-
 #include <klocale.h>
-#include <kconfig.h>
+#include <qlabel.h>
+
 
 #define KJOTSVERSION "0.4"
 
 const unsigned int HOT_LIST_SIZE = 8;
 const unsigned int BUTTON_WIDTH = 56;
 
-extern QString exec_http;
-extern QString exec_ftp;
-
-#include <qvbox.h>
 
 //----------------------------------------------------------------------
 // ASKFILENAME
@@ -105,6 +97,7 @@ void AskFileName::textChanged(const QString &s)
 MyMultiEdit::MyMultiEdit (QWidget* parent, const char* name)
   : KEdit(parent, name)
 {
+  setWordWrap(QTextEdit::WidgetWidth);
   web_menu = new CPopupMenu;
   web_menu->insertItem(i18n("Open URL"), this, SLOT(openUrl()) );
 }
@@ -114,7 +107,7 @@ void MyMultiEdit::keyPressEvent( QKeyEvent *e )
   if( e->key() == Key_Tab )
     {
       int line, col;
-      cursorPosition(&line, &col);
+      getCursorPosition(&line, &col);
       KEdit::insertAt("\t", line, col);
       return;
     }
@@ -124,64 +117,35 @@ void MyMultiEdit::keyPressEvent( QKeyEvent *e )
 
 void MyMultiEdit::mousePressEvent( QMouseEvent *e )
 {
-  if( e->button() == RightButton )
-    {
-      if( hasMarkedText() )
-	{
-	  QString marked = markedText();
-	  if( marked.left(7) == "http://" || marked.left(6) == "ftp://" )
-	    {
-	      web_menu->popup(QCursor::pos());
-	      web_menu->grabMouse();
+  if(e->button() == RightButton)
+  {
+    if(hasMarkedText())
+  	{
+      KURL url(markedText());
+
+      if(url.isValid())
+      {
+  	    web_menu->popup(QCursor::pos());
 	    }
+      
       return;
-	}
-    }
+  	}
+  }
+
   KEdit::mousePressEvent(e);
 }
 
 void MyMultiEdit::openUrl()
 {
-  QString command;
-  int pos;
-  if( hasMarkedText() )
+  if(hasMarkedText())
+  {
+    KURL url(markedText());
+    if(url.isValid())
     {
-      QString marked = markedText();
-      if( marked.left(7) == "http://" )
-	{
-	  command = exec_http;
-	
-	  if( (pos = exec_http.find("%u")) == -1 )
-	    {
-	      command += " " + marked + " &";
-	    }
-	  else
-	    {
-	      command.remove(pos, 2);
-	      command = command.insert(pos, marked);
-	      command += " &";
-	    }
-	  system(QFile::encodeName(command));
-	  //debug("exec: %s", (const char *) command );
-	}
-      else if( marked.left(6) == "ftp://" )
-	{
-	  command = exec_ftp;
-	
-	  if( (pos = exec_ftp.find("%u")) == -1 )
-	    {
-	      command += " " + marked + " &";
-	    }
-	  else
-	    {
-	      command.remove(pos, 2);
-	      command = command.insert(pos, marked);
-	      command += " &";
-	    }
-	  system(QFile::encodeName(command));
-	  //debug("exec: %s", (const char *) command );
-	}
+	     KFileOpenWithHandler fowh;	  
+      (void) new KRun(url);
     }
+  }
 }
 
 //----------------------------------------------------------------------
@@ -191,7 +155,6 @@ void MyMultiEdit::openUrl()
 MyButtonGroup::MyButtonGroup (QWidget* parent, const char* name)
   : QButtonGroup(parent, name)
 {
-  initMetaObject();
 }
 
 void MyButtonGroup::resizeEvent( QResizeEvent * )
@@ -217,24 +180,25 @@ KJotsMain::KJotsMain(const char* name)
   mOptionDialog = 0;
   folderOpen    = FALSE;
   current       = 0;
+  unique_id     = 0;
 
   //
   // Main widget
   //
-  f_main = new QFrame( this, "Frame_0" );
+  QFrame* f_main = new QFrame( this, "Frame_0" );
   f_main->setFrameStyle( QFrame::NoFrame );
   setCentralWidget(f_main);
 
   //
   // Text area
   //
-  f_text = new QFrame( f_main, "Frame_1" );
+  QFrame* f_text = new QFrame( f_main, "Frame_1" );
   f_text->setFrameStyle( QFrame::NoFrame );
 
   //
   // Status bar area
   //
-  f_labels = new QFrame( f_main, "Frame_2" );
+  QFrame* f_labels = new QFrame( f_main, "Frame_2" );
   f_labels->setFrameStyle( QFrame::NoFrame );
 
   //
@@ -295,8 +259,8 @@ KJotsMain::KJotsMain(const char* name)
   button_list.setAutoDelete(TRUE);
 
   subj_list = new SubjList( topLevelWidget(), 0, false );
-  connect( this, SIGNAL(folderChanged(QList<TextEntry> *)),
-	   subj_list, SLOT(rebuildList( QList<TextEntry> *)) );
+  connect( this, SIGNAL(folderChanged(QPtrList<TextEntry> *)),
+	   subj_list, SLOT(rebuildList( QPtrList<TextEntry> *)) );
   connect( this, SIGNAL(entryMoved(int)),
 	   subj_list, SLOT( select(int)) );
   connect( subj_list, SIGNAL(entryMoved(int)),
@@ -315,35 +279,54 @@ KJotsMain::KJotsMain(const char* name)
   while( hotlist.count() > HOT_LIST_SIZE )
     hotlist.remove(hotlist.last());
   // read list of folders
-  folder_list = config->readListEntry( "Folders" );
+  QDir dir(locateLocal("appdata", ""));
+  QString absPath = dir.absPath() + '/';
+  QStringList files = dir.entryList(QDir::Files |  QDir::Readable); // config->readListEntry( "Folders" );
 
   // create hotlist buttons and hotlist menu
-  folders = new QPopupMenu;
-  int i = 0;
+  folders_menu = new QPopupMenu;
   QPushButton *temp_button;
-  for ( QStringList::Iterator it = folder_list.begin();
-        it != folder_list.end();
-        ++it, i++ )
+  for ( QStringList::Iterator it = files.begin();
+        it != files.end();
+        ++it)
   {
-    folders->insertItem(*it, i);
-    if( hotlist.contains(*it) )
+    QFile folder(absPath + *it);
+    if(!folder.open(IO_ReadWrite))
     {
-      temp_button = new QPushButton(*it, bg_top);
+      continue;
+    }
+
+    QTextStream st( (QIODevice *) &folder);
+    QString buf = st.readLine();
+    
+    if(buf.left(9) != "\\NewEntry")
+    {
+      continue;
+    }
+    
+    QString decodedFilename = KURL::decode_string(*it);
+    folder_list.push_back(decodedFilename);
+    folders_menu->insertItem(decodedFilename, unique_id);
+    if(hotlist.contains(decodedFilename))
+    {
+      temp_button = new QPushButton(decodedFilename, bg_top);
       temp_button->setFocusPolicy(QWidget::ClickFocus);
       temp_button->setToggleButton(TRUE);
       temp_button->setFixedSize(BUTTON_WIDTH, temp_button->sizeHint().height());
-      bg_top->insert(temp_button, i);
+      bg_top->insert(temp_button, unique_id);
       button_list.append(temp_button);
     }
+ 
+    ++unique_id;
   }
 
-  unique_id = i+1;
-  connect( folders, SIGNAL(activated(int)), this, SLOT(openFolder(int)) );
+  connect( folders_menu, SIGNAL(activated(int)), this, SLOT(openFolder(int)) );
   connect( bg_top, SIGNAL(clicked(int)), this, SLOT(openFolder(int)) );
 
   updateConfiguration();
 
   // creat keyboard shortcuts
+  // CTRL+Key_J := insert date
   // CTRL+Key_J := previous page
   // CTRL+Key_K := next page
   // CTRL+Key_L := show subject list
@@ -351,128 +334,135 @@ KJotsMain::KJotsMain(const char* name)
   // CTRL+Key_M := move focus
 
   keys = new KAccel( this );
-  keys->insertStdItem( KStdAccel::New, i18n("New Book") );
-
-  keys->connectItem( KStdAccel::New, this, SLOT(createFolder()) );
-  keys->connectItem( KStdAccel::Save , this, SLOT(saveFolder()) );
-  keys->connectItem( KStdAccel::Quit, qApp, SLOT(quit()) );
-  keys->connectItem( KStdAccel::Cut , me_text, SLOT(cut()) );
-  keys->connectItem( KStdAccel::Copy , me_text, SLOT(copyText()) );
-  keys->connectItem( KStdAccel::Paste , me_text, SLOT(paste()) );
-
-  keys->insertItem(i18n("PreviousPage"),    "PreviousPage",    CTRL+Key_J);
-  keys->insertItem(i18n("NextPage"),        "NextPage",        CTRL+Key_K);
-  keys->insertItem(i18n("ShowSubjectList"), "ShowSubjectList", CTRL+Key_L);
-  keys->insertItem(i18n("AddNewPage"),      "AddNewPage",      CTRL+Key_A);
-  keys->insertItem(i18n("DelPage"),          "DelPage",        CTRL+Key_D);
-  keys->insertItem(i18n("MoveFocus"),       "MoveFocus",       CTRL+Key_M);
-  keys->insertItem(i18n("CopySelection"),   "CopySelection",   CTRL+Key_Y);
-  keys->connectItem( "PreviousPage", this, SLOT(prevEntry()) );
-  keys->connectItem( "NextPage", this, SLOT(nextEntry()) );
-  keys->connectItem( "ShowSubjectList", this, SLOT(toggleSubjList()) );
-  keys->connectItem( "AddNewPage", this, SLOT(newEntry()) );
+  keys->insertItem(i18n("Move Focus"),       "MoveFocus",       CTRL+Key_M);
   keys->connectItem( "MoveFocus", this, SLOT(moveFocus()) );
-  keys->connectItem( "CopySelection", this, SLOT(copySelection()) );
-  keys->readSettings();
-
 
   // create menu
   int id;
-  QPopupMenu *file = new QPopupMenu;
-  id = file->insertItem(i18n("&New Book..."), this, SLOT(createFolder()));
-  keys->changeMenuAccel(file, id, KStdAccel::New);
+  KAction *action;
+  QPopupMenu *file_menu = new QPopupMenu;
+  
+  // New Book
+  action = KStdAction::action(KStdAction::New, this, SLOT(createFolder()), actionCollection());
+  action->setText(i18n("&New Book..."));
+  action->plug(file_menu);
 
-  file->insertSeparator();
-  id_f_save_book = file->insertItem(i18n("Save current book"),
-				    this, SLOT(saveFolder()) );
-  keys->changeMenuAccel(file, id_f_save_book, KStdAccel::Save);
-  id_f_save_book_ascii = file->insertItem(i18n("Save book to ascii file"),
-					  this, SLOT(writeBook()) );
-  id_f_save_page_ascii = file->insertItem(i18n("Save page to ascii file"),
-					  this, SLOT(writePage()) );
-  file->insertSeparator();
-  id_f_del_book = file->insertItem(i18n("Delete current book"),
-				   this, SLOT(deleteFolder()) );
-  file->insertSeparator();
-  id = file->insertItem(i18n("&Quit"),
-			qApp, SLOT(quit()));
-  keys->changeMenuAccel(file, id, KStdAccel::Quit);
+  // added more actionized items and toolbar (antonio)
+  action = new KAction(i18n("New P&age"), "filenew", CTRL+Key_A, this,
+                       SLOT(newEntry()), actionCollection(), "new_page");
+  action->plug(file_menu);
+  action->plug(toolBar(0));
+  action->plugAccel(keys);
+
+  file_menu->insertSeparator();
+  
+  // Save Book
+  action = KStdAction::action(KStdAction::Save, this, SLOT(saveFolder()), actionCollection());
+  action->setText(i18n("Save Current Book"));
+  action->plug(file_menu);
+  
+  id_f_save_book_ascii = file_menu->insertItem(i18n("Save Book to ASCII File"),
+					                                     this, SLOT(writeBook()));
+  id_f_save_page_ascii = file_menu->insertItem(i18n("Save Page to ASCII File"),
+					                                     this, SLOT(writePage()));
+
+  file_menu->insertSeparator();
+
+  action = new KAction(i18n("Delete Current Book"), "editdelete", 0, this,
+                       SLOT(deleteFolder()), actionCollection(), "del_folder");
+  action->plug(file_menu);
+  action->plugAccel(keys);
+
+  action = new KAction(i18n("&Delete Page"), "editdelete", CTRL+Key_D, this,
+                       SLOT(deleteEntry()), actionCollection(), "del_page");
+  action->plug(file_menu);
+  action->plug(toolBar(0));
+  action->plugAccel(keys);
+
+  file_menu->insertSeparator();
+
+  // Quit
+  action = KStdAction::action(KStdAction::Quit, this, SLOT(slotQuit()), actionCollection());
+  action->plug(file_menu);
 
   QPopupMenu *edit_menu = new QPopupMenu;
 
-  id_e_cut = edit_menu->insertItem(i18n("C&ut"),
-				   me_text, SLOT(cut()));
-  keys->changeMenuAccel(edit_menu, id_e_cut, KStdAccel::Cut);
-  id_e_copy = edit_menu->insertItem(i18n("&Copy") ,
-				    me_text, SLOT(copyText()) );
-  keys->changeMenuAccel(edit_menu, id_e_copy, KStdAccel::Copy);
-  id_e_paste = edit_menu->insertItem(i18n("&Paste"),
-				     me_text, SLOT(paste()));
-  keys->changeMenuAccel(edit_menu, id_e_paste, KStdAccel::Paste);
+  action = KStdAction::action(KStdAction::Cut, me_text, SLOT(cut()), actionCollection());
+  action->plug(edit_menu);
+  
+  action  = KStdAction::action(KStdAction::Copy, me_text, SLOT(copy()), actionCollection());
+  action->plug(edit_menu);
+
+  action = new KAction(i18n("Copy &Into Page Title"), "editcopy", CTRL+Key_T, this,
+                       SLOT(copySelection()), actionCollection(), "copyIntoTitle");
+  action->plug(edit_menu);
+  action->plugAccel(keys);
+
+  action  = KStdAction::action(KStdAction::Paste, me_text, SLOT(paste()), actionCollection());
+  action->plug(edit_menu);
+  
   edit_menu->insertSeparator();
 
   // added actionized items (pfeiffer)
-  KAction *action = KStdAction::find( this, SLOT( slotSearch() ), me_text );
+  action = KStdAction::find( this, SLOT( slotSearch() ), actionCollection() );
   action->plug( edit_menu );
-  action = KStdAction::findNext( this, SLOT( slotRepeatSearch() ), me_text );
+  action = KStdAction::findNext( this, SLOT( slotRepeatSearch() ), actionCollection() );
   action->plug( edit_menu );
-  action = KStdAction::replace( this, SLOT( slotReplace() ), me_text );
+  action = KStdAction::replace( this, SLOT( slotReplace() ), actionCollection() );
   action->plug( edit_menu );
   edit_menu->insertSeparator();
 
-  // added more actionized items and toolbar (antonio)
-  action=new KAction(i18n("&New Page"), "filenew", 0, this,
-        SLOT(newEntry()), actionCollection(), "new_page");
-  action->plug( edit_menu );
-  action->plug( toolBar(0) );
-
-  action=new KAction(i18n("&Delete Page"), "editdelete", 0, this,
-        SLOT(deleteEntry()), actionCollection(), "del_page");
-  action->plug( edit_menu );
-  action->plug( toolBar(0) );
-
+  action = new KAction(i18n("Insert Date"), "date", CTRL+Key_I, this,
+                       SLOT(insertDate()), actionCollection(), "insert_date");
+  action->plug(edit_menu);
+  action->plug(toolBar(0));
+  action->plugAccel( keys );
   edit_menu->insertSeparator();
-  action=new KAction(i18n("Previous"), "back", 0, this,
-        SLOT(prevEntry()), actionCollection(), "new_page");
-  action->plug( edit_menu );
-  action->plug( toolBar(0) );
 
-  action=new KAction(i18n("Next"), "forward", 0, this,
-        SLOT(nextEntry()), actionCollection(), "del_page");
+  action = new KAction(i18n("Previous Page"), "back", CTRL+Key_J, this,
+                       SLOT(prevEntry()), actionCollection(), "prev_page");
   action->plug( edit_menu );
   action->plug( toolBar(0) );
+  action->plugAccel( keys );
+  action = new KAction(i18n("Next Page"), "forward", CTRL+Key_K, this,
+                       SLOT(nextEntry()), actionCollection(), "next_page");
+  action->plug( edit_menu );
+  action->plug( toolBar(0) );
+  action->plugAccel( keys );
 
   toolBar(0)->insertSeparator();
 
-  QPopupMenu *options = new QPopupMenu;
-  options->insertItem(i18n("Configure &Key Bindings..."),
-		      this, SLOT(configureKeys()) );
-  options->insertItem(i18n("&Configure %1...").arg(kapp->caption()),
-		      this, SLOT(configure()) );
+  QPopupMenu *options_menu = new QPopupMenu;
+  action = KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
+  action->plug(options_menu);
+  /*
+   * TODO: configure toolbar? need to use xmlgui
+   * action = KStdAction::configureToolbars(this, SLOT(configureToolbars()), actionCollection());
+   */
+  action = KStdAction::preferences(this, SLOT(configure()), actionCollection());
+  action->plug(options_menu);
 
-  QPopupMenu *hotlist = new QPopupMenu;
-  id_fav_add = hotlist->insertItem(i18n("Add current book to hotlist"),
-				   this, SLOT(addToHotlist()) );
-  id_fav_del = hotlist->insertItem(i18n("Remove current book from hotlist"),
-				   this, SLOT(removeFromHotlist()) );
+  QPopupMenu *hotlist_menu = new QPopupMenu;
+  id_fav_add = hotlist_menu->insertItem(i18n("Add Current Book to Hotlist"),
+				                                this, SLOT(addToHotlist()) );
+  id_fav_del = hotlist_menu->insertItem(i18n("Remove Current Book from Hotlist"),
+				                                this, SLOT(removeFromHotlist()) );
 
-  action=new KAction(i18n("Subject List"), "view_detailed", 0, this,
+  action=new KAction(i18n("Subject List"), "view_detailed", CTRL+Key_L, this,
         SLOT(toggleSubjList()), actionCollection(), "subject_list");
-  action->plug( hotlist );
-  action->plug( toolBar(0) );
+  action->plug(hotlist_menu);
+  action->plug(toolBar(0));
+  action->plugAccel(keys);
 
-  menuBar()->insertItem( i18n("&File"), file );
+  menuBar()->insertItem( i18n("&File"), file_menu );
   menuBar()->insertItem( i18n("&Edit"), edit_menu );
-  menuBar()->insertItem( i18n("&Books"), folders );
-  menuBar()->insertItem( i18n("Hot&list"), hotlist );
-  menuBar()->insertItem( i18n("&Options"), options );
+  menuBar()->insertItem( i18n("&Books"), folders_menu );
+  menuBar()->insertItem( i18n("Hot&list"), hotlist_menu );
+  menuBar()->insertItem( i18n("&Settings"), options_menu );
   menuBar()->insertSeparator();
-  QString about = "KJots " KJOTSVERSION "\n\r(c) ";
-  about += (QString) i18n("by") +
-    " Christoph Neerfeld\n\rChristoph.Neerfeld@home.ivm.de";
-  menuBar()->insertItem( i18n("&Help"), helpMenu(about ) );
+  menuBar()->insertItem( i18n("&Help"), helpMenu() );
 
-  int nr = folder_list.findIndex( config->readEntry("LastOpenFolder") );
+  int nr = folder_list.findIndex(KURL::decode_string(config->readEntry("LastOpenFolder")));
   if( nr >= 0 )
   {
     openFolder(nr);
@@ -492,6 +482,7 @@ KJotsMain::KJotsMain(const char* name)
   h = QMAX( h, sizeHint().height() );
   resize(w, h);
 
+  keys->readSettings();
   updateMenu();
 }
 
@@ -521,7 +512,6 @@ void KJotsMain::saveProperties( void )
   config.sync();
 }
 
-
 int KJotsMain::readFile( QString name )
 {
   int pos;
@@ -532,10 +522,12 @@ int KJotsMain::readFile( QString name )
   QFile folder(name);
   if( !folder.open(IO_ReadWrite) )
     return -1;
+
   QTextStream st( (QIODevice *) &folder);
   buf = st.readLine();
   if( buf.left(9) != "\\NewEntry" )
     return -1;
+
   entry = new TextEntry;
   entrylist.append( entry );
   subj = buf.mid(10, buf.length() );
@@ -567,15 +559,23 @@ int KJotsMain::readFile( QString name )
   return 0;
 }
 
-int KJotsMain::writeFile( QString name ) {
+int KJotsMain::writeFile( QString name ) 
+{
   int pos;
-  TextEntry *entry;
+  TextEntry *entry = entrylist.first();
   QString buf;
   QFile folder(name);
   if( !folder.open(IO_WriteOnly | IO_Truncate) )
     return -1;
   QTextStream st( (QIODevice *) &folder);
-  for( entry = entrylist.first(); entry != NULL; entry = entrylist.next() )
+
+  if (entry == 0)
+  {
+    st << "\\NewEntry \n\n";
+  }
+  else  
+  {
+    for(; entry != NULL; entry = entrylist.next())
     {
       st << "\\NewEntry ";
       st << entry->subject;
@@ -584,19 +584,27 @@ int KJotsMain::writeFile( QString name ) {
 
       pos = 0;
       while( (pos = buf.find( '\\', pos )) != -1 )
-	{
-	  buf.insert( ++pos, '\\' );
-	  pos++;
-	}
+     	{
+    	  buf.insert( ++pos, '\\' );
+     	  pos++;
+     	}
       st << buf;
       if( buf.right(1) != "\n" )
-	st << '\n';
+       	st << '\n';
     }
+  }
+
   folder.close();
   return 0;
 }
 
-void KJotsMain::openFolder(int id) {
+void KJotsMain::openFolder(int id) 
+{
+  if (folders_menu->indexOf(id) < 0)
+  {
+    return;
+  }
+ 
   QPushButton *but;
   for( but = button_list.first(); but != NULL; but = button_list.next() )
     but->setOn(FALSE);
@@ -607,7 +615,7 @@ void KJotsMain::openFolder(int id) {
   QDir dir = QDir( locateLocal("appdata", "") );
   QString file_name = dir.absPath();
   file_name += '/';
-  file_name += *folder_list.at( folders->indexOf(id) );
+  file_name += KURL::encode_string_no_slash(*folder_list.at(folders_menu->indexOf(id)));
   if( current_folder_name == file_name )
     return;
 
@@ -629,7 +637,7 @@ void KJotsMain::openFolder(int id) {
   emit entryMoved(current);
   le_subject->setText(entrylist.first()->subject);
   folderOpen = TRUE;
-  l_folder->setText( *folder_list.at(folders->indexOf(id)) );
+  l_folder->setText( *folder_list.at(folders_menu->indexOf(id)) );
   me_text->setEnabled(TRUE);
   le_subject->setEnabled(TRUE);
   me_text->setFocus();
@@ -679,15 +687,11 @@ void KJotsMain::createFolder()
 //     if( folders->text(folders->idAt(0)) == 0 )
 //      folders->removeItemAt(0);
 
-  folders->insertItem(name, unique_id++);
+  folders_menu->insertItem(name, unique_id++);
   QDir dir = QDir( locateLocal("appdata", "") );
   current_folder_name = dir.absPath();
   current_folder_name += '/';
-  current_folder_name += name;
-  KConfig *config = KApplication::kApplication()->config();
-  config->setGroup("kjots");
-  config->writeEntry( "Folders", folder_list );
-  config->sync();
+  current_folder_name += KURL::encode_string_no_slash(name);
   l_folder->setText(name);
   QPushButton *but;
   for( but = button_list.first(); but != 0; but = button_list.next() )
@@ -716,8 +720,8 @@ void KJotsMain::deleteFolder()
     return;
   dir.remove(current_folder_name);
   folder_list.remove(folder_list.at(index));
-  int id = folders->idAt(index);
-  folders->removeItemAt(index);
+  int id = folders_menu->idAt(index);
+  folders_menu->removeItemAt(index);
   if( hotlist.contains(name) )
     {
       hotlist.remove(name);
@@ -745,6 +749,7 @@ void KJotsMain::deleteFolder()
   l_folder->clear();
   subj_list->repaint(TRUE);
 
+  openFolder(folders_menu->idAt(0));
   updateMenu();
 }
 
@@ -876,7 +881,7 @@ void KJotsMain::addToHotlist()
   int index = folder_list.findIndex(name);
   if( index < 0 )
     return;
-  int id = folders->idAt(index);
+  int id = folders_menu->idAt(index);
   QPushButton *but = new QPushButton(name, bg_top);
   button_list.append(but);
   bg_top->insert(but, id);
@@ -902,7 +907,7 @@ void KJotsMain::removeFromHotlist()
   int index = folder_list.findIndex(name);
   if( index < 0 )
     return;
-  int id = folders->idAt(index);
+  int id = folders_menu->idAt(index);
   QButton *but = bg_top->find(id);
   bg_top->remove(but);
   button_list.remove( (QPushButton *) but );
@@ -974,13 +979,10 @@ void KJotsMain::updateConfiguration()
   KConfig &config = *kapp->config();
 
   config.setGroup("kjots");
-  exec_http = config.readEntry("execHttp");
-  exec_ftp  = config.readEntry("execFtp");
   QFont font( config.readEntry("EFontFamily"),
 	      config.readNumEntry("EFontSize"),
 	      config.readNumEntry("EFontWeight"),
-	      config.readNumEntry("EFontItalic"),
-	      (QFont::CharSet) config.readNumEntry("EFontCharset") );
+	      config.readNumEntry("EFontItalic"));
   me_text->setFont(font);
 }
 
@@ -1091,31 +1093,54 @@ void KJotsMain::moveFocus()
 
 void KJotsMain::configureKeys()
 {
-  if( KKeyDialog::configureKeys( keys, true, topLevelWidget() ) )
+  if (KKeyDialog::configureKeys(keys, true, topLevelWidget()))
+  {
     keys->writeSettings();
+    kapp->config()->sync();
+    keys->readSettings();
+  }
 }
 
 void KJotsMain::copySelection()
 {
-  me_text->copyText();
-  le_subject->setText(QApplication::clipboard()->text());
+  if(me_text->hasMarkedText())
+  {
+    le_subject->setText(me_text->markedText());
+  }
 }
 
+void KJotsMain::slotQuit() 
+{
+    // just save on exit...
+    saveFolder();
+    close();
+}
+
+void KJotsMain::insertDate()
+{
+  KLocale locale("kjots");
+  QString* date = new QString(locale.formatDateTime(QDateTime::currentDateTime(), true) + " ");
+  QTextStream* dateStream = new QTextStream(date, IO_ReadOnly);
+  me_text->insertText(dateStream);
+  delete dateStream;
+  delete date;
+}
 
 void KJotsMain::updateMenu()
 {
   bool activeBook = folderOpen;
 
-  menuBar()->setItemEnabled(id_f_save_book, activeBook);
+  actionCollection()->action("del_folder")->setEnabled(activeBook);
+  actionCollection()->action("del_page")->setEnabled(activeBook);
+  actionCollection()->action("new_page")->setEnabled(activeBook);
+
+  actionCollection()->action(KStdAction::stdName(KStdAction::Save))->setEnabled(activeBook);
   menuBar()->setItemEnabled(id_f_save_book_ascii, activeBook);
   menuBar()->setItemEnabled(id_f_save_page_ascii, activeBook);
-  menuBar()->setItemEnabled(id_f_del_book, activeBook);
 
-  menuBar()->setItemEnabled(id_e_cut, activeBook);
-  menuBar()->setItemEnabled(id_e_copy, activeBook);
-  menuBar()->setItemEnabled(id_e_paste, activeBook);
-  menuBar()->setItemEnabled(id_e_new, activeBook);
-  menuBar()->setItemEnabled(id_e_del, activeBook);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Cut))->setEnabled(activeBook);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Copy))->setEnabled(activeBook);
+  actionCollection()->action(KStdAction::stdName(KStdAction::Paste))->setEnabled(activeBook);
 
   menuBar()->setItemEnabled(id_fav_add, activeBook);
   menuBar()->setItemEnabled(id_fav_del, activeBook);
